@@ -51,10 +51,11 @@ class CadqueryView(object):
         width=600,
         height=400,
         bb_factor=1.01,
-        quality=0.1,
-        angular_tolerance=0.1,
-        edge_accuracy=0.01,
-        optimal_bb=True,
+        quality=None,
+        deviation=0.5,
+        angular_tolerance=0.3,
+        edge_accuracy=None,
+        optimal_bb=False,
         render_edges=True,
         render_shapes=True,
         info=None,
@@ -66,8 +67,9 @@ class CadqueryView(object):
 
         self.width = width
         self.height = height
-        self.quality = quality
         self.bb_factor = bb_factor
+        self.quality = quality
+        self.deviation = deviation
         self.angular_tolerance = angular_tolerance
         self.edge_accuracy = edge_accuracy
         self.optimal_bb = optimal_bb
@@ -86,7 +88,7 @@ class CadqueryView(object):
         self.default_edge_color = Color((128, 128, 128))
 
         self.camera_distance_factor = 6
-        self.camera_initial_zoom = 2.5
+        self.camera_initial_zoom = zoom
 
         self.features = ["mesh", "edges"]
 
@@ -105,9 +107,8 @@ class CadqueryView(object):
         self.renderer = None
 
         self.camera_position = None
-        self.zoom = None
 
-        self.savestate = None
+        self.savestate = ((0, 0, 0, "XYZ"), (0, 0, 0))
 
     def get_transparent(self):
         # if one object is transparent, all are
@@ -274,6 +275,7 @@ class CadqueryView(object):
     def create(self):
         self.cq_renderer = CadqueryRenderer(
             quality=self.quality,
+            deviation=self.deviation,
             angular_tolerance=self.angular_tolerance,
             edge_accuracy=self.edge_accuracy,
             render_edges=self.render_edges,
@@ -313,7 +315,7 @@ class CadqueryView(object):
         )
         return self.renderer
 
-    def add_shapes(self, shapes, progress, position=None, rotation=None, zoom=2.5, reset=True):
+    def add_shapes(self, shapes, progress, position=None, rotation=None, zoom=None, reset=True):
         def all_shapes(shapes, loc=None):
             loc = shapes["loc"] if loc is None else loc * shapes["loc"]
             result = []
@@ -349,16 +351,19 @@ class CadqueryView(object):
         bb_max = self.bb.max_dist_from_center()
         orbit_radius = 4 * self.bb_factor * bb_max
 
+        if reset:
+            self._reset()
+
         # Calculate camera postion
         if position is None and rotation is None:  # no new defaults
-            if reset or self.camera_position is None:  # no existing position
+            if self.camera_position is None:  # no existing position
                 self.camera_position = self._add(self.bb.center, self._scale((1, 1, 1)))
         else:
             position = rotate(position or (1, 1, 1), *(rotation or (0, 0, 0)))
             self.camera_position = self._add(self.bb.center, self._scale(position))
 
-        if reset or self.zoom is None:
-            self.zoom = zoom
+        if self.zoom is None:
+            self.zoom = self.camera_initial_zoom
 
         # Set up Helpers relative to bounding box
         xy_max = max(abs(self.bb.xmin), abs(self.bb.xmax), abs(self.bb.ymin), abs(self.bb.ymax)) * 1.2
@@ -376,6 +381,7 @@ class CadqueryView(object):
         # Set up the controller relative to bounding box
         self.controller.target = self.bb.center
         self.controller.target0 = self.bb.center
+        self.controller.panSpeed = (self.bb.xsize + self.bb.ysize + self.bb.zsize) / 300
 
         # Set up lights in every of the 8 corners of the global bounding box
         positions = list(itertools.product(*[(-orbit_radius, orbit_radius)] * 3))
