@@ -14,7 +14,18 @@
 # limitations under the License.
 #
 
-from .cad_objects import Assembly, Part, Faces, Edges, Vertices, show, auto_show
+from .cad_objects import (
+    Assembly,
+    PartGroup,
+    Part,
+    Faces,
+    Edges,
+    Vertices,
+    show,
+    auto_show,
+    show_accuracy,
+    show_constraints,
+)
 from .replay import replay, enable_replay, disable_replay, reset_replay
 
 auto_show()
